@@ -10,24 +10,28 @@ setClass("TENxMatrixSeed", contains="CSC_H5SparseMatrixSeed")
 ### Low-level helpers
 ###
 
-### Return the rownames of the matrix.
-.get_tenx_genes <- function(filepath, group)
+.find_rownames_dataset <- function(filepath, group)
 {
-    if (!h5exists(filepath, paste0(group, "/genes")))
-        return(NULL)
-    read_h5sparse_component(filepath, group, "genes")
+    name <- "genes"
+    if (h5exists(filepath, paste(group, name, sep="/")))
+        return(name)
+    name <- "features/id"
+    if (h5exists(filepath, paste(group, name, sep="/")))
+        return(name)
+    NULL
 }
 
-### Currently unused.
-.get_tenx_gene_names <- function(filepath, group)
+### Return the rownames of the matrix.
+.load_tenx_rownames <- function(filepath, group)
 {
-    if (!h5exists(filepath, paste0(group, "/gene_names")))
+    name <- .find_rownames_dataset(filepath, group)
+    if (is.null(name))
         return(NULL)
-    read_h5sparse_component(filepath, group, "gene_names")
+    read_h5sparse_component(filepath, group, name)
 }
 
 ### Return the colnames of the matrix.
-.get_tenx_barcodes <- function(filepath, group)
+.load_tenx_barcodes <- function(filepath, group)
 {
     if (!h5exists(filepath, paste0(group, "/barcodes")))
         return(NULL)
@@ -39,14 +43,14 @@ setClass("TENxMatrixSeed", contains="CSC_H5SparseMatrixSeed")
 ### Constructor
 ###
 
-TENxMatrixSeed <- function(filepath, group="mm10")
+TENxMatrixSeed <- function(filepath, group="matrix")
 {
     seed0 <- H5SparseMatrixSeed(filepath, group)
 
     ## dimnames
-    rownames <- .get_tenx_genes(seed0@filepath, seed0@group)
+    rownames <- .load_tenx_rownames(seed0@filepath, seed0@group)
     stopifnot(is.null(rownames) || length(rownames) == seed0@dim[[1L]])
-    colnames <- .get_tenx_barcodes(seed0@filepath, seed0@group)
+    colnames <- .load_tenx_barcodes(seed0@filepath, seed0@group)
     stopifnot(is.null(colnames) || length(colnames) == seed0@dim[[2L]])
     dimnames <- list(rownames, colnames)
 
